/**   \file  suite_modmgr-modules.c
 *   \brief  Check ModMgr module management
 *  \author  François Cerbelle (Fanfan), francois@cerbelle.net
 *
 *  \internal
 *       Created:  29/01/2024
 *      Revision:  none
 * Last modified:  2024-07-27 17:28
 *      Compiler:  gcc
 *  Organization:  Cerbelle.net
 *     Copyright:  Copyright (c) 2024, François Cerbelle
 *
 *  This source code is released for free distribution under the terms of the
 *  GNU General Public License as published by the Free Software Foundation.
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "modmgr.h"
#include "oom.h"                                /* OOM simulation */
#include <check.h>
#include <unistd.h>                             /* pid_t getpid() */
#include <sys/stat.h>                           /* mkdir(), chdir(), mode_t */
#include <stdio.h>                              /* fprintf */
#include <stdlib.h>                             /* abort() */
#include <string.h>                             /* strdup */
#include "checktools.inc"

/*
 * Module management :
 * - from = uninitialized, empty, 1 module (mkmod1), 1 module (mkmod1:2),
 * 3 modules (mkmod1, mkmod2, mkmod3)
 * 3 modules (mkmod1:2, mkmod2, mkmod3)
 * 3 modules (mkmod1, mkmod2:2, mkmod3)
 * 3 modules (mkmod1, mkmod2, mkmod3:2)
 * 3 modules (mkmod1:2, mkmod2:2, mkmod3)
 * 3 modules (mkmod1:2, mkmod2, mkmod3:2)
 * 3 modules (mkmod1:2, mkmod2:2, mkmod3:2)
 *
 * load (normal, OOM, overflow)
 * - modfile = NULL, empty, missing, normal, subfolder, PATH_MAX+1, noOnLoad, noOnUnload, noGetSymbol, badInfos, badAPI
 *
 * getsymbol (normal, OOM, overflow)
 * - module = NULL, normal, noOnLoad, noOnUnload, noGetSymbol, badInfos, badAPI
 * - szSymbol = NULL, empty, missing, normal,
 *
 * unload (normal, OOM, overflow)
 * - module = NULL, normal, noOnLoad, noOnUnload, noGetSymbol, badInfos, badAPI
 *
 * */
START_TEST(modmgr_modules_dummy)
{
}
END_TEST

/************************************************************************/
void load_uninitialized_unchecked_setup()
{
    forktest_init();
}
void load_uninitialized_checked_setup()
{
    signals_catch();
    forktest_gprofdir();
}
void load_uninitialized_checked_teardown()
{
    signals_release();
}
void load_uninitialized_unchecked_teardown() { }

Suite* modmgr_modules_suite()
{
    Suite *s;
    TCase *tc;

    s = suite_create("ModMgr-Modules");

    tc = tcase_create("Uninitialized");
    tcase_add_checked_fixture(tc, load_uninitialized_checked_setup, load_uninitialized_checked_teardown);
    tcase_add_unchecked_fixture(tc, load_uninitialized_unchecked_setup, load_uninitialized_unchecked_teardown);
    suite_add_tcase(s, tc);
    tcase_add_test(tc, modmgr_modules_dummy);

    return s;
}

